# Pluggy
A Plugin and Permission plugin in Python for Endstone


## Installing via pip
- Go to your terminal 
- Type: pip install endstone-pluggy
## Usage
Type /pluggy for the menu

## Permissions

pluggy.command.use

pluggy.list

pluggy.plugin.toggle

pluggy.plugin.download

pluggy.perms.list

pluggy.perms.toggle
